# cgx-notebooks
Repository to distribute CloudGenix Python Notebooks and easily install helper functions.

#### Synopsis
Helper functions and example .ipynb files for notebooks for use with CloudGenix

#### Requirements
* Active CloudGenix Account
* Python modules:
    * cloudgenix >=5.2.1b1 - <https://github.com/CloudGenix/sdk-python>
    * cloudgenix_idname>=2.0.1 - 
    * plotly>=4.5.2 - 
    * pandas>=1.0.1 - 
    * numpy -
    * IPython - 
    * ipywidgets - 
    * fuzzywuzzy - 
    * python-levenshtein - 

#### License
MIT

#### Version
Version | Changes
------- | --------
**1.0.0-99**| Aaron tweak releases - view commit notes for details.